from viset.imagenet import ImageNetFall2011
from viset.dataset import Viset
from viset.show import imshow

if __name__ == '__main__':
  # Create a new viset
  print 'Creating vision dataset for imagenet-fall2011'
  dbfile = ImageNetFall2011().export()
  print 'Exporting dataset to redistributable HDF5 file "' + dbfile + '"'
  
  # Import an existing viset 
  print 'Displaying all images in viset (VISion dataSET) "' + dbfile + '"'
  db = Viset(dbfile)
  for (im,annotation) in db.read(n_skip=100):
    print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
    if im is not None:
      imshow(im)
      sleep(0.2)


